# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Lobby Server

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model


class ModelNativeFriendSyncResponse(Model):
    """Model native friend sync response (model.NativeFriendSyncResponse)

    Properties:
        platform_id: (platformId) REQUIRED str

        status: (status) REQUIRED str

        detail: (detail) OPTIONAL str
    """

    # region fields

    platform_id: str  # REQUIRED
    status: str  # REQUIRED
    detail: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_platform_id(self, value: str) -> ModelNativeFriendSyncResponse:
        self.platform_id = value
        return self

    def with_status(self, value: str) -> ModelNativeFriendSyncResponse:
        self.status = value
        return self

    def with_detail(self, value: str) -> ModelNativeFriendSyncResponse:
        self.detail = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "platform_id"):
            result["platformId"] = str(self.platform_id)
        elif include_empty:
            result["platformId"] = ""
        if hasattr(self, "status"):
            result["status"] = str(self.status)
        elif include_empty:
            result["status"] = ""
        if hasattr(self, "detail"):
            result["detail"] = str(self.detail)
        elif include_empty:
            result["detail"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls, platform_id: str, status: str, detail: Optional[str] = None, **kwargs
    ) -> ModelNativeFriendSyncResponse:
        instance = cls()
        instance.platform_id = platform_id
        instance.status = status
        if detail is not None:
            instance.detail = detail
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelNativeFriendSyncResponse:
        instance = cls()
        if not dict_:
            return instance
        if "platformId" in dict_ and dict_["platformId"] is not None:
            instance.platform_id = str(dict_["platformId"])
        elif include_empty:
            instance.platform_id = ""
        if "status" in dict_ and dict_["status"] is not None:
            instance.status = str(dict_["status"])
        elif include_empty:
            instance.status = ""
        if "detail" in dict_ and dict_["detail"] is not None:
            instance.detail = str(dict_["detail"])
        elif include_empty:
            instance.detail = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelNativeFriendSyncResponse]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelNativeFriendSyncResponse]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelNativeFriendSyncResponse,
        List[ModelNativeFriendSyncResponse],
        Dict[Any, ModelNativeFriendSyncResponse],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "platformId": "platform_id",
            "status": "status",
            "detail": "detail",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "platformId": True,
            "status": True,
            "detail": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: operation.j2

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

# AccelByte Gaming Services Lobby Server

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import ApiError, ApiResponse
from accelbyte_py_sdk.core import Operation
from accelbyte_py_sdk.core import HeaderStr
from accelbyte_py_sdk.core import HttpResponse
from accelbyte_py_sdk.core import deprecated

from ...models import ResponseError


class AdminExportConfigV1(Operation):
    """Export lobby config to a json file. (adminExportConfigV1)

    Export lobby configuration to a json file. The file can then be imported from the /import endpoint.

    JSON Schema of the exported file:
    {
    "required": [
    "namespace",
    "entitlementItemID",
    "chatRateLimitDuration",
    "unregisterDelay",
    "generalRateLimitDuration",
    "autoKickOnDisconnectDelay",
    "chatRateLimitBurst",
    "generalRateLimitBurst",
    "maxPartyMember",
    "autoKickOnDisconnect",
    "profanityFilter",
    "enableChat",
    "entitlementCheck",
    "cancelTicketOnDisconnect",
    "concurrentUsersLimit",
    "readyConsentTimeout",
    "disableInvitationOnJoinParty",
    "allowJoinPartyDuringMatchmaking",
    "allowInviteNonConnectedUser",
    "keepPresenceActivityOnDisconnect",
    "maxDSWaitTime",
    "maxFriendsLimit",
    "requestMetadataMaxSize"
    ],
    "properties": {
    "allowInviteNonConnectedUser": {
    "type": "boolean"
    },
    "allowJoinPartyDuringMatchmaking": {
    "type": "boolean"
    },
    "autoKickOnDisconnect": {
    "type": "boolean"
    },
    "autoKickOnDisconnectDelay": {
    "type": "integer",
    "format": "int64"
    },
    "cancelTicketOnDisconnect": {
    "type": "boolean"
    },
    "chatRateLimitBurst": {
    "type": "integer",
    "format": "int32"
    },
    "chatRateLimitDuration": {
    "type": "integer",
    "format": "int64"
    },
    "concurrentUsersLimit": {
    "type": "integer",
    "format": "int32"
    },
    "disableInvitationOnJoinParty": {
    "type": "boolean"
    },
    "enableChat": {
    "type": "boolean"
    },
    "entitlementCheck": {
    "type": "boolean"
    },
    "entitlementItemID": {
    "type": "string"
    },
    "generalRateLimitBurst": {
    "type": "integer",
    "format": "int32"
    },
    "generalRateLimitDuration": {
    "type": "integer",
    "format": "int64"
    },
    "keepPresenceActivityOnDisconnect": {
    "type": "boolean"
    },
    "maxDSWaitTime": {
    "type": "integer",
    "format": "int64"
    },
    "maxFriendsLimit": {
    "type": "integer",
    "format": "int32"
    },
    "maxPartyMember": {
    "type": "integer",
    "format": "int32"
    },
    "namespace": {
    "type": "string"
    },
    "profanityFilter": {
    "type": "boolean"
    },
    "readyConsentTimeout": {
    "type": "integer",
    "format": "int64"
    },
    "requestMetadataMaxSize": {
    "type": "integer",
    "format": "int32"
    },
    "unregisterDelay": {
    "type": "integer",
    "format": "int64"
    },
    "wsReadTimeout": {
    "type": "integer",
    "format": "int64"
    }
    }
    }

    Properties:
        url: /lobby/v1/admin/config/namespaces/{namespace}/export

        method: GET

        tags: ["config"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - Any (OK
            JSON Schema of the exported file:
            {
             "required": [
              "namespace",
              "entitlementItemID",
              "chatRateLimitDuration",
              "unregisterDelay",
              "generalRateLimitDuration",
              "autoKickOnDisconnectDelay",
              "chatRateLimitBurst",
              "generalRateLimitBurst",
              "maxPartyMember",
              "autoKickOnDisconnect",
              "profanityFilter",
              "enableChat",
              "entitlementCheck",
              "cancelTicketOnDisconnect",
              "concurrentUsersLimit",
              "readyConsentTimeout",
              "disableInvitationOnJoinParty",
              "allowJoinPartyDuringMatchmaking",
              "allowInviteNonConnectedUser",
              "keepPresenceActivityOnDisconnect",
              "maxDSWaitTime",
              "maxFriendsLimit",
              "requestMetadataMaxSize"
             ],
             "properties": {
              "allowInviteNonConnectedUser": {
               "type": "boolean"
              },
              "allowJoinPartyDuringMatchmaking": {
               "type": "boolean"
              },
              "autoKickOnDisconnect": {
               "type": "boolean"
              },
              "autoKickOnDisconnectDelay": {
               "type": "integer",
               "format": "int64"
              },
              "cancelTicketOnDisconnect": {
               "type": "boolean"
              },
              "chatRateLimitBurst": {
               "type": "integer",
               "format": "int32"
              },
              "chatRateLimitDuration": {
               "type": "integer",
               "format": "int64"
              },
              "concurrentUsersLimit": {
               "type": "integer",
               "format": "int32"
              },
              "disableInvitationOnJoinParty": {
               "type": "boolean"
              },
              "enableChat": {
               "type": "boolean"
              },
              "entitlementCheck": {
               "type": "boolean"
              },
              "entitlementItemID": {
               "type": "string"
              },
              "generalRateLimitBurst": {
               "type": "integer",
               "format": "int32"
              },
              "generalRateLimitDuration": {
               "type": "integer",
               "format": "int64"
              },
              "keepPresenceActivityOnDisconnect": {
               "type": "boolean"
              },
              "maxDSWaitTime": {
               "type": "integer",
               "format": "int64"
              },
              "maxFriendsLimit": {
               "type": "integer",
               "format": "int32"
              },
              "maxPartyMember": {
               "type": "integer",
               "format": "int32"
              },
              "namespace": {
               "type": "string"
              },
              "profanityFilter": {
               "type": "boolean"
              },
              "readyConsentTimeout": {
               "type": "integer",
               "format": "int64"
              },
              "requestMetadataMaxSize": {
               "type": "integer",
               "format": "int32"
              },
              "unregisterDelay": {
               "type": "integer",
               "format": "int64"
              },
              "wsReadTimeout": {
               "type": "integer",
               "format": "int64"
              }
             }
            })

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """

    # region fields

    _url: str = "/lobby/v1/admin/config/namespaces/{namespace}/export"
    _path: str = "/lobby/v1/admin/config/namespaces/{namespace}/export"
    _base_path: str = ""
    _method: str = "GET"
    _consumes: List[str] = []
    _produces: List[str] = ["application/json"]
    _securities: List[List[str]] = [["BEARER_AUTH"]]
    _location_query: str = None

    service_name: Optional[str] = "lobby"

    namespace: str  # REQUIRED in [path]

    # endregion fields

    # region properties

    @property
    def url(self) -> str:
        return self._url

    @property
    def path(self) -> str:
        return self._path

    @property
    def base_path(self) -> str:
        return self._base_path

    @property
    def method(self) -> str:
        return self._method

    @property
    def consumes(self) -> List[str]:
        return self._consumes

    @property
    def produces(self) -> List[str]:
        return self._produces

    @property
    def securities(self) -> List[List[str]]:
        return self._securities

    @property
    def location_query(self) -> str:
        return self._location_query

    # endregion properties

    # region get methods

    # endregion get methods

    # region get_x_params methods

    def get_all_params(self) -> dict:
        return {
            "path": self.get_path_params(),
        }

    def get_path_params(self) -> dict:
        result = {}
        if hasattr(self, "namespace"):
            result["namespace"] = self.namespace
        return result

    # endregion get_x_params methods

    # region is/has methods

    # endregion is/has methods

    # region with_x methods

    def with_namespace(self, value: str) -> AdminExportConfigV1:
        self.namespace = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "namespace") and self.namespace:
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        return result

    # endregion to methods

    # region response methods

    class Response(ApiResponse):
        data_200: Optional[Any] = None
        error_401: Optional[ResponseError] = None
        error_403: Optional[ResponseError] = None
        error_500: Optional[ResponseError] = None

        def ok(self) -> AdminExportConfigV1.Response:
            if self.error_401 is not None:
                err = self.error_401.translate_to_api_error()
                exc = err.to_exception()
                if exc is not None:
                    raise exc  # pylint: disable=raising-bad-type
            if self.error_403 is not None:
                err = self.error_403.translate_to_api_error()
                exc = err.to_exception()
                if exc is not None:
                    raise exc  # pylint: disable=raising-bad-type
            if self.error_500 is not None:
                err = self.error_500.translate_to_api_error()
                exc = err.to_exception()
                if exc is not None:
                    raise exc  # pylint: disable=raising-bad-type
            return self

        def __iter__(self):
            if self.data_200 is not None:
                yield self.data_200
                yield None
            elif self.error_401 is not None:
                yield None
                yield self.error_401
            elif self.error_403 is not None:
                yield None
                yield self.error_403
            elif self.error_500 is not None:
                yield None
                yield self.error_500
            else:
                yield None
                yield self.error

    # noinspection PyMethodMayBeStatic
    def parse_response(self, code: int, content_type: str, content: Any) -> Response:
        """Parse the given response.

        200: OK - Any (OK
        JSON Schema of the exported file:
        {
         "required": [
          "namespace",
          "entitlementItemID",
          "chatRateLimitDuration",
          "unregisterDelay",
          "generalRateLimitDuration",
          "autoKickOnDisconnectDelay",
          "chatRateLimitBurst",
          "generalRateLimitBurst",
          "maxPartyMember",
          "autoKickOnDisconnect",
          "profanityFilter",
          "enableChat",
          "entitlementCheck",
          "cancelTicketOnDisconnect",
          "concurrentUsersLimit",
          "readyConsentTimeout",
          "disableInvitationOnJoinParty",
          "allowJoinPartyDuringMatchmaking",
          "allowInviteNonConnectedUser",
          "keepPresenceActivityOnDisconnect",
          "maxDSWaitTime",
          "maxFriendsLimit",
          "requestMetadataMaxSize"
         ],
         "properties": {
          "allowInviteNonConnectedUser": {
           "type": "boolean"
          },
          "allowJoinPartyDuringMatchmaking": {
           "type": "boolean"
          },
          "autoKickOnDisconnect": {
           "type": "boolean"
          },
          "autoKickOnDisconnectDelay": {
           "type": "integer",
           "format": "int64"
          },
          "cancelTicketOnDisconnect": {
           "type": "boolean"
          },
          "chatRateLimitBurst": {
           "type": "integer",
           "format": "int32"
          },
          "chatRateLimitDuration": {
           "type": "integer",
           "format": "int64"
          },
          "concurrentUsersLimit": {
           "type": "integer",
           "format": "int32"
          },
          "disableInvitationOnJoinParty": {
           "type": "boolean"
          },
          "enableChat": {
           "type": "boolean"
          },
          "entitlementCheck": {
           "type": "boolean"
          },
          "entitlementItemID": {
           "type": "string"
          },
          "generalRateLimitBurst": {
           "type": "integer",
           "format": "int32"
          },
          "generalRateLimitDuration": {
           "type": "integer",
           "format": "int64"
          },
          "keepPresenceActivityOnDisconnect": {
           "type": "boolean"
          },
          "maxDSWaitTime": {
           "type": "integer",
           "format": "int64"
          },
          "maxFriendsLimit": {
           "type": "integer",
           "format": "int32"
          },
          "maxPartyMember": {
           "type": "integer",
           "format": "int32"
          },
          "namespace": {
           "type": "string"
          },
          "profanityFilter": {
           "type": "boolean"
          },
          "readyConsentTimeout": {
           "type": "integer",
           "format": "int64"
          },
          "requestMetadataMaxSize": {
           "type": "integer",
           "format": "int32"
          },
          "unregisterDelay": {
           "type": "integer",
           "format": "int64"
          },
          "wsReadTimeout": {
           "type": "integer",
           "format": "int64"
          }
         }
        })

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)

        ---: HttpResponse (Undocumented Response)

        ---: HttpResponse (Unexpected Content-Type Error)

        ---: HttpResponse (Unhandled Error)
        """
        result = AdminExportConfigV1.Response()

        pre_processed_response, error = self.pre_process_response(
            code=code, content_type=content_type, content=content
        )

        if error is not None:
            if not error.is_no_content():
                result.error = ApiError.create_from_http_response(error)
        else:
            code, content_type, content = pre_processed_response

            if code == 200:
                result.data_200 = content
            elif code == 401:
                result.error_401 = ResponseError.create_from_dict(content)
                result.error = result.error_401.translate_to_api_error()
            elif code == 403:
                result.error_403 = ResponseError.create_from_dict(content)
                result.error = result.error_403.translate_to_api_error()
            elif code == 500:
                result.error_500 = ResponseError.create_from_dict(content)
                result.error = result.error_500.translate_to_api_error()
            else:
                result.error = ApiError.create_from_http_response(
                    HttpResponse.create_undocumented_response(
                        code=code, content_type=content_type, content=content
                    )
                )

        result.status_code = str(code)
        result.content_type = content_type

        if 400 <= code <= 599 or result.error is not None:
            result.is_success = False

        return result

    # noinspection PyMethodMayBeStatic
    @deprecated
    def parse_response_x(
        self, code: int, content_type: str, content: Any
    ) -> Tuple[Union[None, Any], Union[None, HttpResponse, ResponseError]]:
        """Parse the given response.

        200: OK - Any (OK
        JSON Schema of the exported file:
        {
         "required": [
          "namespace",
          "entitlementItemID",
          "chatRateLimitDuration",
          "unregisterDelay",
          "generalRateLimitDuration",
          "autoKickOnDisconnectDelay",
          "chatRateLimitBurst",
          "generalRateLimitBurst",
          "maxPartyMember",
          "autoKickOnDisconnect",
          "profanityFilter",
          "enableChat",
          "entitlementCheck",
          "cancelTicketOnDisconnect",
          "concurrentUsersLimit",
          "readyConsentTimeout",
          "disableInvitationOnJoinParty",
          "allowJoinPartyDuringMatchmaking",
          "allowInviteNonConnectedUser",
          "keepPresenceActivityOnDisconnect",
          "maxDSWaitTime",
          "maxFriendsLimit",
          "requestMetadataMaxSize"
         ],
         "properties": {
          "allowInviteNonConnectedUser": {
           "type": "boolean"
          },
          "allowJoinPartyDuringMatchmaking": {
           "type": "boolean"
          },
          "autoKickOnDisconnect": {
           "type": "boolean"
          },
          "autoKickOnDisconnectDelay": {
           "type": "integer",
           "format": "int64"
          },
          "cancelTicketOnDisconnect": {
           "type": "boolean"
          },
          "chatRateLimitBurst": {
           "type": "integer",
           "format": "int32"
          },
          "chatRateLimitDuration": {
           "type": "integer",
           "format": "int64"
          },
          "concurrentUsersLimit": {
           "type": "integer",
           "format": "int32"
          },
          "disableInvitationOnJoinParty": {
           "type": "boolean"
          },
          "enableChat": {
           "type": "boolean"
          },
          "entitlementCheck": {
           "type": "boolean"
          },
          "entitlementItemID": {
           "type": "string"
          },
          "generalRateLimitBurst": {
           "type": "integer",
           "format": "int32"
          },
          "generalRateLimitDuration": {
           "type": "integer",
           "format": "int64"
          },
          "keepPresenceActivityOnDisconnect": {
           "type": "boolean"
          },
          "maxDSWaitTime": {
           "type": "integer",
           "format": "int64"
          },
          "maxFriendsLimit": {
           "type": "integer",
           "format": "int32"
          },
          "maxPartyMember": {
           "type": "integer",
           "format": "int32"
          },
          "namespace": {
           "type": "string"
          },
          "profanityFilter": {
           "type": "boolean"
          },
          "readyConsentTimeout": {
           "type": "integer",
           "format": "int64"
          },
          "requestMetadataMaxSize": {
           "type": "integer",
           "format": "int32"
          },
          "unregisterDelay": {
           "type": "integer",
           "format": "int64"
          },
          "wsReadTimeout": {
           "type": "integer",
           "format": "int64"
          }
         }
        })

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)

        ---: HttpResponse (Undocumented Response)

        ---: HttpResponse (Unexpected Content-Type Error)

        ---: HttpResponse (Unhandled Error)
        """
        pre_processed_response, error = self.pre_process_response(
            code=code, content_type=content_type, content=content
        )
        if error is not None:
            return None, None if error.is_no_content() else error
        code, content_type, content = pre_processed_response

        if code == 200:
            return content, None
        if code == 401:
            return None, ResponseError.create_from_dict(content)
        if code == 403:
            return None, ResponseError.create_from_dict(content)
        if code == 500:
            return None, ResponseError.create_from_dict(content)

        return self.handle_undocumented_response(
            code=code, content_type=content_type, content=content
        )

    # endregion response methods

    # region static methods

    @classmethod
    def create(cls, namespace: str, **kwargs) -> AdminExportConfigV1:
        instance = cls()
        instance.namespace = namespace
        if x_flight_id := kwargs.get("x_flight_id", None):
            instance.x_flight_id = x_flight_id
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> AdminExportConfigV1:
        instance = cls()
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        return instance

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "namespace": "namespace",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "namespace": True,
        }

    # endregion static methods
